==> trade-center-api-0.0.2-20160816.072751-35-sources.jar: cn/com/duiba/order/center/api/dto/OrdersViewDto.java <==
package cn.com.duiba.order.center.api.dto;

import java.util.Date;

public class OrdersViewDto {

	private Long id;
	private Date gmtCreate;//订单创建时间
	private String orderNum;//兑吧订单号
	private String developerBizId;//开发者的业务id
	private String partnerUserId;//用户id	
	private String exchangeType;//商品信息
	private Long credits;//积分
	private Integer actualPrice;//金额
	private String payStatus;
	private String payStatusClass;//资金状态
	private String orderStatus;
	private String orderStatusClass;
	private String orderStatusClass2;
	private String auditStatus;//订单状态
	private String auditStatusClass;//状态类型
	private String status;
	private String error4Developer;
	private String error4Admin;
	private String errorMessage;

	private String appName;
	private String bizParams;
	private String orderType;
	
	private String brief;
	
	private boolean entity;//是否为实物商品
	private String[] express;
	
	private String remarks;
	
	private Boolean allowInputAgain;
	private String turntableOrderNum;
	private Integer fasterType;
	private String singleLotteryOrderNum;
	private String hdToolOrderNum;
	
	private Date finishTime;// 订单结束时间 
	private Long relationId;// 关联对象id，如果ChargeMode=turntable，则此为大转盘订单id
	private Integer relationType;
	private boolean cancelEnble;
	private Integer hdToolType;
	private boolean abnormalEnble;
	
	public String getOrderStatusClass2() {
		return orderStatusClass2;
	}
	public void setOrderStatusClass2(String orderStatusClass2) {
		this.orderStatusClass2 = orderStatusClass2;
	}
	public Date getFinishTime() {
		return finishTime;
	}
	public void setFinishTime(Date finishTime) {
		this.finishTime = finishTime;
	}
	public Long getRelationId() {
		return relationId;
	}
	public void setRelationId(Long relationId) {
		this.relationId = relationId;
	}
	public Integer getRelationType() {
		return relationType;
	}
	public void setRelationType(Integer relationType) {
		this.relationType = relationType;
	}
	public Integer getHdToolType() {
		return hdToolType;
	}
	public void setHdToolType(Integer hdToolType) {
		this.hdToolType = hdToolType;
	}
	public String getHdToolOrderNum() {
		return hdToolOrderNum;
	}
	public void setHdToolOrderNum(String hdToolOrderNum) {
		this.hdToolOrderNum = hdToolOrderNum;
	}
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
	public String getOrderNum() {
		return orderNum;
	}
	public void setOrderNum(String orderNum) {
		this.orderNum = orderNum;
	}
	public String getDeveloperBizId() {
		return developerBizId;
	}
	public void setDeveloperBizId(String developerBizId) {
		this.developerBizId = developerBizId;
	}
	public String getPartnerUserId() {
		return partnerUserId;
	}
	public void setPartnerUserId(String partnerUserId) {
		this.partnerUserId = partnerUserId;
	}
	public String getExchangeType() {
		return exchangeType;
	}
	public void setExchangeType(String exchangeType) {
		this.exchangeType = exchangeType;
	}
	public Long getCredits() {
		return credits;
	}
	public void setCredits(Long credits) {
		this.credits = credits;
	}
	public Integer getActualPrice() {
		return actualPrice;
	}
	public void setActualPrice(Integer actualPrice) {
		this.actualPrice = actualPrice;
	}
	public String getPayStatus() {
		return payStatus;
	}
	public void setPayStatus(String payStatus) {
		this.payStatus = payStatus;
	}
	public String getPayStatusClass() {
		return payStatusClass;
	}
	public void setPayStatusClass(String payStatusClass) {
		this.payStatusClass = payStatusClass;
	}
	public String getOrderStatus() {
		return orderStatus;
	}
	public void setOrderStatus(String orderStatus) {
		this.orderStatus = orderStatus;
	}
	public String getOrderStatusClass() {
		return orderStatusClass;
	}
	public void setOrderStatusClass(String orderStatusClass) {
		this.orderStatusClass = orderStatusClass;
	}
	public String getAuditStatus() {
		return auditStatus;
	}
	public void setAuditStatus(String auditStatus) {
		this.auditStatus = auditStatus;
	}
	public String getAuditStatusClass() {
		return auditStatusClass;
	}
	public void setAuditStatusClass(String auditStatusClass) {
		this.auditStatusClass = auditStatusClass;
	}
	public String getStatus() {
		return status;
	}
	public void setStatus(String status) {
		this.status = status;
	}
	public String getError4Developer() {
		return error4Developer;
	}
	public void setError4Developer(String error4Developer) {
		this.error4Developer = error4Developer;
	}
	public String getErrorMessage() {
		return errorMessage;
	}
	public void setErrorMessage(String errorMessage) {
		this.errorMessage = errorMessage;
	}
	public String getAppName() {
		return appName;
	}
	public void setAppName(String appName) {
		this.appName = appName;
	}
	public String getBizParams() {
		return bizParams;
	}
	public void setBizParams(String bizParams) {
		this.bizParams = bizParams;
	}
	public String getOrderType() {
		return orderType;
	}
	public void setOrderType(String orderType) {
		this.orderType = orderType;
	}

	public boolean isEntity() {
		return entity;
	}
	public void setEntity(boolean entity) {
		this.entity = entity;
	}
	public String[] getExpress() {
		return express;
	}
	public void setExpress(String[] express) {
		this.express = express;
	}
	public String getBrief() {
		return brief;
	}
	public void setBrief(String brief) {
		this.brief = brief;
	}
	public String getRemarks() {
		return remarks;
	}
	public void setRemarks(String remarks) {
		this.remarks = remarks;
	}
	public String getError4Admin() {
		return error4Admin;
	}
	public void setError4Admin(String error4Admin) {
		this.error4Admin = error4Admin;
	}

	public Boolean getAllowInputAgain() {
		return allowInputAgain;
	}
	public void setAllowInputAgain(Boolean allowInputAgain) {
		this.allowInputAgain = allowInputAgain;
	}
	public String getTurntableOrderNum() {
		return turntableOrderNum;
	}
	public void setTurntableOrderNum(String turntableOrderNum) {
		this.turntableOrderNum = turntableOrderNum;
	}
	public Integer getFasterType() {
		return fasterType;
	}
	public void setFasterType(Integer fasterType) {
		this.fasterType = fasterType;
	}
	public String getSingleLotteryOrderNum() {
		return singleLotteryOrderNum;
	}
	public void setSingleLotteryOrderNum(String singleLotteryOrderNum) {
		this.singleLotteryOrderNum = singleLotteryOrderNum;
	}
	public boolean isCancelEnble() {
		return cancelEnble;
	}
	public void setCancelEnble(boolean cancelEnble) {
		this.cancelEnble = cancelEnble;
	}
	public boolean isAbnormalEnble() {
		return abnormalEnble;
	}
	public void setAbnormalEnble(boolean abnormalEnble) {
		this.abnormalEnble = abnormalEnble;
	}

}

==> trade-center-api-0.1.1-20160825.062748-15-sources.jar: cn/com/duiba/order/center/api/dto/OrdersViewDto.java <==
package cn.com.duiba.order.center.api.dto;

import java.io.Serializable;
import java.util.Date;

public class OrdersViewDto implements Serializable{

	/**
	 * 
	 */
	private static final long serialVersionUID = 6950734573650073317L;
	private Long id;
	private Date gmtCreate;//订单创建时间
	private String orderNum;//兑吧订单号
	private String developerBizId;//开发者的业务id
	private String partnerUserId;//用户id	
	private String exchangeType;//商品信息
	private Long credits;//积分
	private Integer actualPrice;//金额
	private String payStatus;
	private String payStatusClass;//资金状态
	private String orderStatus;
	private String orderStatusClass;
	private String orderStatusClass2;
	private String auditStatus;//订单状态
	private String auditStatusClass;//状态类型
	private String status;
	private String error4Developer;
	private String error4Admin;
	private String errorMessage;

	private String appName;
	private String bizParams;
	private String orderType;
	
	private String brief;
	
	private boolean entity;//是否为实物商品
	private String[] express;
	
	private String remarks;
	
	private Boolean allowInputAgain;
	private String turntableOrderNum;
	private Integer fasterType;
	private String singleLotteryOrderNum;
	private String hdToolOrderNum;
	
	private Date finishTime;// 订单结束时间 
	private Long relationId;// 关联对象id，如果ChargeMode=turntable，则此为大转盘订单id
	private Integer relationType;
	private boolean cancelEnble;
	private Integer hdToolType;
	private boolean abnormalEnble;
	
	public String getOrderStatusClass2() {
		return orderStatusClass2;
	}
	public void setOrderStatusClass2(String orderStatusClass2) {
		this.orderStatusClass2 = orderStatusClass2;
	}
	public Date getFinishTime() {
		return finishTime;
	}
	public void setFinishTime(Date finishTime) {
		this.finishTime = finishTime;
	}
	public Long getRelationId() {
		return relationId;
	}
	public void setRelationId(Long relationId) {
		this.relationId = relationId;
	}
	public Integer getRelationType() {
		return relationType;
	}
	public void setRelationType(Integer relationType) {
		this.relationType = relationType;
	}
	public Integer getHdToolType() {
		return hdToolType;
	}
	public void setHdToolType(Integer hdToolType) {
		this.hdToolType = hdToolType;
	}
	public String getHdToolOrderNum() {
		return hdToolOrderNum;
	}
	public void setHdToolOrderNum(String hdToolOrderNum) {
		this.hdToolOrderNum = hdToolOrderNum;
	}
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
	public String getOrderNum() {
		return orderNum;
	}
	public void setOrderNum(String orderNum) {
		this.orderNum = orderNum;
	}
	public String getDeveloperBizId() {
		return developerBizId;
	}
	public void setDeveloperBizId(String developerBizId) {
		this.developerBizId = developerBizId;
	}
	public String getPartnerUserId() {
		return partnerUserId;
	}
	public void setPartnerUserId(String partnerUserId) {
		this.partnerUserId = partnerUserId;
	}
	public String getExchangeType() {
		return exchangeType;
	}
	public void setExchangeType(String exchangeType) {
		this.exchangeType = exchangeType;
	}
	public Long getCredits() {
		return credits;
	}
	public void setCredits(Long credits) {
		this.credits = credits;
	}
	public Integer getActualPrice() {
		return actualPrice;
	}
	public void setActualPrice(Integer actualPrice) {
		this.actualPrice = actualPrice;
	}
	public String getPayStatus() {
		return payStatus;
	}
	public void setPayStatus(String payStatus) {
		this.payStatus = payStatus;
	}
	public String getPayStatusClass() {
		return payStatusClass;
	}
	public void setPayStatusClass(String payStatusClass) {
		this.payStatusClass = payStatusClass;
	}
	public String getOrderStatus() {
		return orderStatus;
	}
	public void setOrderStatus(String orderStatus) {
		this.orderStatus = orderStatus;
	}
	public String getOrderStatusClass() {
		return orderStatusClass;
	}
	public void setOrderStatusClass(String orderStatusClass) {
		this.orderStatusClass = orderStatusClass;
	}
	public String getAuditStatus() {
		return auditStatus;
	}
	public void setAuditStatus(String auditStatus) {
		this.auditStatus = auditStatus;
	}
	public String getAuditStatusClass() {
		return auditStatusClass;
	}
	public void setAuditStatusClass(String auditStatusClass) {
		this.auditStatusClass = auditStatusClass;
	}
	public String getStatus() {
		return status;
	}
	public void setStatus(String status) {
		this.status = status;
	}
	public String getError4Developer() {
		return error4Developer;
	}
	public void setError4Developer(String error4Developer) {
		this.error4Developer = error4Developer;
	}
	public String getErrorMessage() {
		return errorMessage;
	}
	public void setErrorMessage(String errorMessage) {
		this.errorMessage = errorMessage;
	}
	public String getAppName() {
		return appName;
	}
	public void setAppName(String appName) {
		this.appName = appName;
	}
	public String getBizParams() {
		return bizParams;
	}
	public void setBizParams(String bizParams) {
		this.bizParams = bizParams;
	}
	public String getOrderType() {
		return orderType;
	}
	public void setOrderType(String orderType) {
		this.orderType = orderType;
	}

	public boolean isEntity() {
		return entity;
	}
	public void setEntity(boolean entity) {
		this.entity = entity;
	}
	public String[] getExpress() {
		return express;
	}
	public void setExpress(String[] express) {
		this.express = express;
	}
	public String getBrief() {
		return brief;
	}
	public void setBrief(String brief) {
		this.brief = brief;
	}
	public String getRemarks() {
		return remarks;
	}
	public void setRemarks(String remarks) {
		this.remarks = remarks;
	}
	public String getError4Admin() {
		return error4Admin;
	}
	public void setError4Admin(String error4Admin) {
		this.error4Admin = error4Admin;
	}

	public Boolean getAllowInputAgain() {
		return allowInputAgain;
	}
	public void setAllowInputAgain(Boolean allowInputAgain) {
		this.allowInputAgain = allowInputAgain;
	}
	public String getTurntableOrderNum() {
		return turntableOrderNum;
	}
	public void setTurntableOrderNum(String turntableOrderNum) {
		this.turntableOrderNum = turntableOrderNum;
	}
	public Integer getFasterType() {
		return fasterType;
	}
	public void setFasterType(Integer fasterType) {
		this.fasterType = fasterType;
	}
	public String getSingleLotteryOrderNum() {
		return singleLotteryOrderNum;
	}
	public void setSingleLotteryOrderNum(String singleLotteryOrderNum) {
		this.singleLotteryOrderNum = singleLotteryOrderNum;
	}
	public boolean isCancelEnble() {
		return cancelEnble;
	}
	public void setCancelEnble(boolean cancelEnble) {
		this.cancelEnble = cancelEnble;
	}
	public boolean isAbnormalEnble() {
		return abnormalEnble;
	}
	public void setAbnormalEnble(boolean abnormalEnble) {
		this.abnormalEnble = abnormalEnble;
	}

}
